/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.html.link;

import org.apache.wicket.MockPageWithLink;
import org.apache.wicket.model.Model;
import org.apache.wicket.util.tester.TagTester;
import org.apache.wicket.util.tester.WicketTester;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

/**
 * Tests for {@link AbstractLink}
 */
public class AbstractLinkTest
{

	private WicketTester wicketTester;

	@Before
	public void before()
	{
		wicketTester = new WicketTester();
	}

	@After
	public void after()
	{
		wicketTester.destroy();
	}

	/**
	 * 
	 * @see <a href="https://issues.apache.org/jira/browse/WICKET-3338">WICKET-3338</a>
	 */
	@Test
	public void testSetBodyModel()
	{
		final String linkBody = "Link body";

		MockPageWithLink mockPageWithLink = new MockPageWithLink();
		AbstractLink link = new AbstractLink("link")
		{
			private static final long serialVersionUID = 1L;
		};
		link.setMarkupId("link");
		link.setBody(Model.of(linkBody));
		mockPageWithLink.add(link);

		wicketTester.startPage(mockPageWithLink);
		TagTester tagTester = wicketTester.getTagById("link");
		Assert.assertEquals(linkBody, tagTester.getValue());
	}

}
